local VERSION = tonumber(("$Revision: 43146 $"):match("%d+"))

Parrot = AceLibrary("AceAddon-2.0"):new("AceDB-2.0", "AceConsole-2.0", "FuBarPlugin-2.0", "Parser-3.0", "AceModuleCore-2.0")
local Parrot, self = Parrot, Parrot
Parrot.version = "r" .. VERSION
Parrot.revision = VERSION
Parrot.date = ("$Date: 2007-07-07 21:31:48 -0400 (Sat, 07 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")

local _G = _G

local localeTables = {}
function Parrot:L(name, defaultTable)
	if not localeTables[name] then
		localeTables[name] = setmetatable(defaultTable or {}, {__index = function(self, key)
			self[key] = key
			return key
		end})
	end
	return localeTables[name]
end

local L = Parrot:L("Parrot")

Parrot:RegisterDB("ParrotDB")
Parrot:RegisterDefaults('profile', {
	font = "Friz Quadrata TT",
	fontSize = 20,
})

-- FuBar configuration
Parrot.hasIcon = [[Interface\Icons\Spell_Nature_ForceOfNature]]
Parrot.hideWithoutStandby = true
Parrot.defaultPosition = "MINIMAP"
Parrot.defaultMinimapPosition = 250
Parrot.hasNoText = true
Parrot.hasNoColor = true
Parrot.cannotDetachTooltip = true
Parrot.independentProfile = true
Parrot.blizzardTooltip = true

local new, del, newHash, newSet, deepCopy, deepDel
do
	local list = setmetatable({}, {__mode='k'})
	function new(...)
		local t = next(list)
		if t then
			list[t] = nil
			for i = 1, select('#', ...) do
				t[i] = select(i, ...)
			end
			return t
		else
			return { ... }
		end
	end
	
	function newHash(...)
		local t = next(list)
		if t then
			list[t] = nil
		else
			t = {}
		end
		for i = 1, select('#', ...), 2 do
			t[select(i, ...)] = select(i+1, ...)
		end
		return t
	end
	
	function newSet(...)
		local t = next(list)
		if t then
			list[t] = nil
		else
			t = {}
		end
		for i = 1, select('#', ...) do
			t[select(i, ...)] = true
		end
		return t
	end
	
	function del(t)
		for k in pairs(t) do
			t[k] = nil
		end
		t[''] = true
		t[''] = nil
		list[t] = true
		return nil
	end
	
	function deepCopy(from)
		if type(from) ~= "table" then
			return from
		end
		local to = new()
		for k,v in pairs(from) do
			to[k] = deepCopy(v)
		end
		return to
	end

	function deepDel(t)
		if type(t) ~= "table" then
			return nil
		end
		for k,v in pairs(t) do
			t[k] = deepDel(v)
		end
		return del(t)
	end
end
Parrot.new = new
Parrot.newHash = newHash
Parrot.newSet = newSet
Parrot.del = del
Parrot.deepCopy = deepCopy
Parrot.deepDel = deepDel

function Parrot:OnInitialize()
	self:RegisterChatCommand('/Parrot', '/Par', {
		type = 'execute',
		func = function()
			self:OpenMenu()
		end
	})
end

local registeredWaterfall = false
function Parrot:OnClick()
	if AceLibrary:HasInstance("Waterfall-1.0") then
		if not registeredWaterfall then
			registeredWaterfall = true
			AceLibrary("Waterfall-1.0"):Register("Parrot", 
								"aceOptions", Parrot.options,
								"title", L["Parrot Configuration"],
								"treeLevels", 5)
		end
		AceLibrary("Waterfall-1.0"):Open("Parrot")
	else
		self:Print(L["Waterfall-1.0 is required to access the GUI."])
	end
end

Parrot.options = {
	type = 'group',
	handler = Parrot,
	args = {
	}
}

Parrot.OnMenuRequest = Parrot.options

function Parrot:OnTooltipUpdate()
	GameTooltip:AddLine("Parrot")
	GameTooltip:AddLine(" ")
	if AceLibrary:HasInstance("Waterfall-1.0") then
		GameTooltip:AddLine(L["|cffffff00Left-Click|r to change settings with a nice GUI configuration."], 0.2, 1, 0.2)
	end
	GameTooltip:AddLine(L["|cffffff00Right-Click|r to change settings with a drop-down menu."], 0.2, 1, 0.2)
end
